@@ -5,7 +5,7 @@
 #ifndef _BYTESWAP_H
 #define _BYTESWAP_H
 
-#include <klibc/compiler.h>
+#include <sys/types.h>
 #include <asm/byteorder.h>
 
 #define bswap_16(x) __swab16(x)
