@@ -71,8 +71,8 @@ __extern int fchmod(int, mode_t);
 __extern int mkdir(const char *, mode_t);
 __extern int mkdirat(int, const char *, mode_t);
 __extern int rmdir(const char *);
-__extern int pipe(int *);
-__extern int pipe2(int *, int);
+__extern int pipe(int[2]);
+__extern int pipe2(int[2], int);
 __extern int chroot(const char *);
 __extern int symlink(const char *, const char *);
 __extern int symlinkat(const char *, int, const char *);
